import os

from celery import Celery
from dotenv import load_dotenv
from kombu import Queue, Exchange

from eventbus.routes import ROUTES

load_dotenv()

SERVICE_NAME = os.environ["SERVICE_NAME"]

RABBIT_HOST = os.environ["AWS_MQ_RABBITMQ_URL"]
RABBIT_PORT = os.getenv("AWS_MQ_RABBITMQ_PORT", "5671")
RABBIT_USER = os.getenv("AWS_MQ_RABBITMQ_USER", "guest")
RABBIT_PASS = os.getenv("AWS_MQ_RABBITMQ_PASSWORD", "guest")

BROKER_URL = f'amqps://{RABBIT_USER}:{RABBIT_PASS}@{RABBIT_HOST}:{RABBIT_PORT}'

app = Celery('eventbus', include=['eventbus.handlers'])
app.conf.update({
    'broker_url': BROKER_URL,
    'task_routes': ROUTES,
    'task_queues': (
        Queue('broadcast_events', Exchange('broadcast_events', type='fanout', durable=True),
              routing_key='broadcast_events'),
    ),
})



import os

from dotenv import load_dotenv

load_dotenv()


SERVICES_NAME = os.getenv("SERVICES_NAME", "").split(",")
SERVICES_NAME = [service.strip() for service in SERVICES_NAME if service.strip()]

def create_direct_routes(services):
    """ Generates direct routing for each service. """
    return {
        f'events.{service}.*': {
            'queue': f'{service}_queue',
            'exchange': 'services_exchange',
            'exchange_type': 'direct',
            'routing_key': service
        }
        for service in services
    }

BROADCAST_ROUTES = {
    'events.*': {
        'queue': 'broadcast_events',
        'exchange': 'broadcast_events',
        'exchange_type': 'fanout',
        'binding_key': 'broadcast_events'
    }
}

ROUTES = {**BROADCAST_ROUTES, **create_direct_routes(SERVICES_NAME)}



from setuptools import setup, find_packages

setup(
    name="eventbus_sdk",
    version="1.0.4",
    packages=find_packages(),
    install_requires=[
        "celery",
        "kombu",
        "python-dotenv",
    ],
    description="Internal SDK for event-driven microservices communication",
    url="https://github.com/WildWildLeads/eventbus",
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
)
